============
Symbol Icons
============

The Icons for every symbol is also available for usage through code, not the
Qt Designer.
Like the Symbols, all the Icons are based on the same super class and share a
set of common properties that can be used to tweak its look and feel.


Gauges
------

============ ========== ============================================================
Name         Icon       Import
============ ========== ============================================================
Rough        |rough|    ``from pcdswidgets.icons import RoughGaugeSymbolIcon``
Cathode      |cathode|  ``from pcdswidgets.icons import CathodeGaugeSymbolIcon``
Hot Cathode  |hcathode| ``from pcdswidgets.icons import HotCathodeGaugeSymbolIcon``
Cold Cathode |ccathode| ``from pcdswidgets.icons import ColdCathodeGaugeSymbolIcon``
============ ========== ============================================================

.. |rough| image:: /_static/icons/RoughGaugeSymbolIcon.png
.. |cathode| image:: /_static/icons/CathodeGaugeSymbolIcon.png
.. |hcathode| image:: /_static/icons/HotCathodeGaugeSymbolIcon.png
.. |ccathode| image:: /_static/icons/ColdCathodeGaugeSymbolIcon.png


Valves
------

================== =========== =================================================================
Name               Icon        Import
================== =========== =================================================================
Pneumatic          |pneuvalve| ``from pcdswidgets.icons import PneumaticValveSymbolIcon``
Pneumatic NO       |pnnovalve| ``from pcdswidgets.icons import PneumaticValveNOSymbolIcon``
Pneumatic DA       |pndavalve| ``from pcdswidgets.icons import PneumaticValveNOSymbolIcon``
Aperture           |aperture|  ``from pcdswidgets.icons import ApertureValveSymbolIcon``
Fast Shutter       |fshutter|  ``from pcdswidgets.icons import FastShutterSymbolIcon``
Right Angle Manual |ramvalve|  ``from pcdswidgets.icons import RightAngleManualValveSymbolIcon``
Needle             |nvalve|    ``from pcdswidgets.icons import NeedleValveSymbolIcon``
Proportional       |propvalve| ``from pcdswidgets.icons import ProportionalValveSymbolIcon``
ControlValve       |control|   ``from pcdswidgets.icons import ControlValveSymbolIcon``
ControlOnlyValve   |cntrlonly| ``from pcdswidgets.icons import ControlOnlyValveSymbolIcon``
================== =========== =================================================================

.. |pneuvalve| image:: /_static/icons/PneumaticValveSymbolIcon.png
.. |pnnovalve| image:: /_static/icons/PneumaticValveNOSymbolIcon.png
.. |pndavalve| image:: /_static/icons/PneumaticValveDASymbolIcon.png
.. |aperture| image:: /_static/icons/ApertureValveSymbolIcon.png
.. |fshutter| image:: /_static/icons/FastShutterSymbolIcon.png
.. |ramvalve| image:: /_static/icons/RightAngleManualValveSymbolIcon.png
.. |nvalve| image:: /_static/icons/NeedleValveSymbolIcon.png
.. |propvalve| image:: /_static/icons/ProportionalValveSymbolIcon.png
.. |control| image:: /_static/icons/ControlValveSymbolIcon.png
.. |cntrlonly| image:: /_static/icons/ControlOnlyValveSymbolIcon.png


Pumps
------

============ ========== ============================================================
Name         Icon       Import
============ ========== ============================================================
Ion          |ionp|     ``from pcdswidgets.icons import IonPumpSymbolIcon``
Turbo        |turbop|   ``from pcdswidgets.icons import TurboPumpSymbolIcon``
Scroll       |scrollp|  ``from pcdswidgets.icons import ScrollPumpSymbolIcon``
Getter       |getter|   ``from pcdswidgets.icons import GetterPumpSymbolIcon``
============ ========== ============================================================

.. |ionp| image:: /_static/icons/IonPumpSymbolIcon.png
.. |turbop| image:: /_static/icons/TurboPumpSymbolIcon.png
.. |scrollp| image:: /_static/icons/ScrollPumpSymbolIcon.png
.. |getter| image:: /_static/icons/GetterPumpSymbolIcon.png


Others
------

============ ========== ============================================================
Name         Icon       Import
============ ========== ============================================================
RGA          |rga|      ``from pcdswidgets.icons import RGASymbolIcon``
============ ========== ============================================================

.. |rga| image:: /_static/icons/RGASymbolIcon.png
